"""Repository interfaces for multiline string indentation fixer."""

from .file_repository import FileRepository
from .parser_repository import ParserRepository

__all__ = ['FileRepository', 'ParserRepository']