"""Data Transfer Objects for the application layer."""
from .fix_file_result import FixFileResult
from .fix_directory_result import FixDirectoryResult

__all__ = ['FixFileResult', 'FixDirectoryResult']